Error

Type Alias Error 

pub type Error = Error;
The Error enum of this pallet.

Aliased Type

pub enum Error {
Show 36 variants PoolNotFound, PoolMemberNotFound, RewardPoolNotFound, SubPoolsNotFound, AccountBelongsToOtherPool, FullyUnbonding, MaxUnbondingLimit, CannotWithdrawAny, MinimumBondNotMet, OverflowRisk, NotDestroying, NotNominator, NotKickerOrDestroying, NotOpen, MaxPools, MaxPoolMembers, CanNotChangeState, DoesNotHavePermission, MetadataExceedsMaxLen, Defensive(DefensiveError), PartialUnbondNotAllowedPermissionlessly, MaxCommissionRestricted, CommissionExceedsMaximum, CommissionExceedsGlobalMaximum, CommissionChangeThrottled, CommissionChangeRateNotAllowed, NoPendingCommission, NoCommissionCurrentSet, PoolIdInUse, InvalidPoolId, BondExtraRestricted, NothingToAdjust, NothingToSlash, AlreadyMigrated, NotMigrated, NotSupported,
}

Variants



PoolNotFound

A (bonded) pool id does not exist.



PoolMemberNotFound

An account is not a member.



RewardPoolNotFound

A reward pool does not exist. In all cases this is a system logic error.



SubPoolsNotFound

A sub pool does not exist.



AccountBelongsToOtherPool

An account is already delegating in another pool. An account may only belong to one pool at a time.



FullyUnbonding

The member is fully unbonded (and thus cannot access the bonded and reward pool anymore to, for example, collect rewards).



MaxUnbondingLimit

The member cannot unbond further chunks due to reaching the limit.



CannotWithdrawAny

None of the funds can be withdrawn yet because the bonding duration has not passed.



MinimumBondNotMet

The amount does not meet the minimum bond to either join or create a pool.

The depositor can never unbond to a value less than Pallet::depositor_min_bond. The caller does not have nominating permissions for the pool. Members can never unbond to a value below MinJoinBond.



OverflowRisk

The transaction could not be executed due to overflow risk for the pool.



NotDestroying

A pool must be in [PoolState::Destroying] in order for the depositor to unbond or for other members to be permissionlessly unbonded.



NotNominator

The caller does not have nominating permissions for the pool.



NotKickerOrDestroying

Either a) the caller cannot make a valid kick or b) the pool is not destroying.



NotOpen

The pool is not open to join



MaxPools

The system is maxed out on pools.



MaxPoolMembers

Too many members in the pool or system.



CanNotChangeState

The pools state cannot be changed.



DoesNotHavePermission

The caller does not have adequate permissions.



MetadataExceedsMaxLen

Metadata exceeds [Config::MaxMetadataLen]



Defensive(DefensiveError)

Some error occurred that should never happen. This should be reported to the maintainers.



PartialUnbondNotAllowedPermissionlessly

Partial unbonding now allowed permissionlessly.



MaxCommissionRestricted

The pool’s max commission cannot be set higher than the existing value.



CommissionExceedsMaximum

The supplied commission exceeds the max allowed commission.



CommissionExceedsGlobalMaximum

The supplied commission exceeds global maximum commission.



CommissionChangeThrottled

Not enough blocks have surpassed since the last commission update.



CommissionChangeRateNotAllowed

The submitted changes to commission change rate are not allowed.



NoPendingCommission

There is no pending commission to claim.



NoCommissionCurrentSet

No commission current has been set.



PoolIdInUse

Pool id currently in use.



InvalidPoolId

Pool id provided is not correct/usable.



BondExtraRestricted

Bonding extra is restricted to the exact pending reward amount.



NothingToAdjust

No imbalance in the ED deposit for the pool.



NothingToSlash

No slash pending that can be applied to the member.



AlreadyMigrated

The pool or member delegation has already migrated to delegate stake.



NotMigrated

The pool or member delegation has not migrated yet to delegate stake.



NotSupported

This call is not allowed in the current state of the pallet.