Error

Type Alias Error 

pub type Error = Error;
Error for the treasury pallet.

Aliased Type

pub enum Error {
    InvalidIndex,
    TooManyApprovals,
    InsufficientPermission,
    ProposalNotApproved,
    FailedToConvertBalance,
    SpendExpired,
    EarlyPayout,
    AlreadyAttempted,
    PayoutError,
    NotAttempted,
    Inconclusive,
}

Variants



InvalidIndex

No proposal, bounty or spend at that index.



TooManyApprovals

Too many approvals in the queue.



InsufficientPermission

The spend origin is valid but the amount it is allowed to spend is lower than the amount to be spent.



ProposalNotApproved

Proposal has not been approved.



FailedToConvertBalance

The balance of the asset kind is not convertible to the balance of the native asset.



SpendExpired

The spend has expired and cannot be claimed.



EarlyPayout

The spend is not yet eligible for payout.



AlreadyAttempted

The payment has already been attempted.



PayoutError

There was some issue with the mechanism of payment.



NotAttempted

The payout was not yet attempted/claimed.



Inconclusive

The payment has neither failed nor succeeded yet.