pub type Error = Error;Expand description
Error for the System pallet
Aliased Type
pub enum Error {
InvalidSpecName,
SpecVersionNeedsToIncrease,
FailedToExtractRuntimeVersion,
NonDefaultComposite,
NonZeroRefCount,
CallFiltered,
MultiBlockMigrationsOngoing,
NothingAuthorized,
Unauthorized,
}Variants
InvalidSpecName
The name of specification does not match between the current runtime and the new runtime.
SpecVersionNeedsToIncrease
The specification version is not allowed to decrease between the current runtime and the new runtime.
FailedToExtractRuntimeVersion
Failed to extract the runtime version from the new runtime.
Either calling Core_version or decoding RuntimeVersion failed.
NonDefaultComposite
Suicide called when the account has non-default composite data.
NonZeroRefCount
There is a non-zero reference count preventing the account from being purged.
CallFiltered
The origin filter prevent the call to be dispatched.
MultiBlockMigrationsOngoing
A multi-block migration is ongoing and prevents the current code from being replaced.
NothingAuthorized
No upgrade authorized.
The submitted code is not authorized.